@@ -37,7 +37,6 @@ import java.util.List;
 import java.util.zip.CRC32;
 import java.util.zip.DataFormatException;
 
-import static net.lingala.zip4j.util.FileUtils.isZipEntryDirectory;
 import static net.lingala.zip4j.util.Zip4jUtil.getCompressionMethod;
 
 public class ZipInputStream extends InputStream {
@@ -49,7 +48,6 @@ public class ZipInputStream extends InputStream {
   private LocalFileHeader localFileHeader;
   private CRC32 crc32 = new CRC32();
   private byte[] endOfEntryBuffer;
-  private boolean extraDataRecordReadForThisEntry = false;
   private boolean canSkipExtendedLocalFileHeader = false;
   private Charset charset;
 
@@ -102,11 +100,7 @@ public class ZipInputStream extends InputStream {
       canSkipExtendedLocalFileHeader = false;
     }
 
-    if (!isZipEntryDirectory(localFileHeader.getFileName())) {
-      this.decompressedInputStream = initializeEntryInputStream(localFileHeader);
-    }
-
-    this.extraDataRecordReadForThisEntry = false;
+    this.decompressedInputStream = initializeEntryInputStream(localFileHeader);
     return localFileHeader;
   }
 
@@ -119,7 +113,7 @@ public class ZipInputStream extends InputStream {
       return -1;
     }
 
-    return b[0];
+    return b[0] & 0xff;
   }
 
   @Override
@@ -143,14 +137,6 @@ public class ZipInputStream extends InputStream {
       return -1;
     }
 
-    if (localFileHeader.isDirectory()) {
-      if (!extraDataRecordReadForThisEntry) {
-        readExtendedLocalFileHeaderIfPresent();
-        extraDataRecordReadForThisEntry = true;
-      }
-      return -1;
-    }
-
     try {
       int readLen = decompressedInputStream.read(b, off, len);
 
@@ -295,12 +281,7 @@ public class ZipInputStream extends InputStream {
       return -1;
     }
 
-    long compressedSize = localFileHeader.getCompressedSize();
-    if (localFileHeader.getZip64ExtendedInfo() != null) {
-      compressedSize = localFileHeader.getZip64ExtendedInfo().getCompressedSize();
-    }
-
-    return compressedSize - getEncryptionHeaderSize(localFileHeader);
+    return localFileHeader.getCompressedSize() - getEncryptionHeaderSize(localFileHeader);
   }
 
   private int getEncryptionHeaderSize(LocalFileHeader localFileHeader) {
